@@ -42,6 +42,7 @@ class PGG_diffusion:
         cooperator_ratio=0.0,
         noise_var=0.0,
         maxlen_queue=200,
+        buffer_size = 100
         ):
 
         import collections
@@ -55,7 +56,7 @@ class PGG_diffusion:
         self._nb_def = collections.deque(maxlen=maxlen_queue)
         self._infected_node = [RD.randint(0,(self._nb_node-1)) for x in xrange(self._nb_seeder)]
         self._simulation_time = 0
-        self._buffer_size = 100
+        self._buffer_size = buffer_size
         self.reset_send_update()
 
         for nd in self._G.nodes_iter():
